"""
pycord.audio
~~~~~~~~~~~~
Lavalink Module For Pycord

:copyright: 2020 PythonistaGuild & 2021 Pycord
:license: MIT see LICENSE for more info
"""

from .client import Client
from .errors import *
from .eqs import *
from .events import *
from .player import *
from .node import Node
from .meta import audioMixin
from .websocket import WebSocket
